@@ -7,16 +7,15 @@ from ..core.topic import topic
 
 # NLP to Structured Query Service - converts natural language to GraphQL
 
-class NLPToStructuredQueryRequest(Record):
-    natural_language_query = String()
+class QuestionToStructuredQueryRequest(Record):
+    question = String()
     max_results = Integer()
-    context_hints = Map(String())  # Optional context for query generation
 
-class NLPToStructuredQueryResponse(Record):
+class QuestionToStructuredQueryResponse(Record):
     error = Error()
     graphql_query = String()  # Generated GraphQL query
     variables = Map(String())  # GraphQL variables if any
     detected_schemas = Array(String())  # Which schemas the query targets
     confidence = Double()
 
-############################################################################
\ No newline at end of file
+############################################################################
